import { type FragmentDefinitionNode } from 'graphql';
type DefinitionAST = unknown;
type DefinitionParser<T extends DefinitionAST> = (documentString: string) => {
    name: string;
    node: T;
}[];
type DefinitionEntry<T extends DefinitionAST, TExtra> = {
    fileName: string;
    extra: TExtra;
    documentString: string;
    definitionName: string;
    node: T;
};
type AffectedDefinitonNameHistoryEntry = {
    updated: Set<string>;
    appeared: Set<string>;
    disappeared: Set<string>;
};
export declare class DefinitionFileStore<T extends DefinitionAST, TExtra = unknown> {
    private _storeVersion;
    private _affectedDefinitonNameHistories;
    private _mapByFileName;
    private _uniqueRecordMap;
    private _duplicatedRecordMap;
    private _parse;
    private _enabledDebugAssertInvaliant;
    constructor({ parse, enabledDebugAssertInvaliant, }: {
        parse: DefinitionParser<T>;
        enabledDebugAssertInvaliant?: boolean;
    });
    assertInvariant(): void;
    getStoreVersion(): number;
    getDetailedAffectedDefinitions(from: number): AffectedDefinitonNameHistoryEntry[];
    getSummarizedAffectedDefinitions(from: number): Set<string>;
    getUniqueDefinitonMap(): Map<string, DefinitionEntry<T, TExtra>>;
    getDuplicatedDefinitonMap(): Map<string, DefinitionEntry<T, TExtra>[]>;
    updateDocuments(fileName: string, documents: {
        text: string;
        extra: TExtra;
    }[]): void;
    private _assert;
    private _addValueToRecordMaps;
    private _removeValueFromRecordMaps;
}
type FragmentRegistryCreateOptions = {
    logger: (msg: string) => void;
};
export declare class FragmentRegistry {
    private _fileVersionMap;
    private _store;
    private _externalFragmentsCache;
    private _logger;
    constructor(options?: FragmentRegistryCreateOptions);
    getFileCurrentVersion(fileName: string): string | undefined;
    getFragmentDefinitions(): FragmentDefinitionNode[];
    getFragmentDefinitionsWithMap(): {
        definitions: FragmentDefinitionNode[];
        map: Map<string, FragmentDefinitionNode>;
    };
    getFragmentDefinitionEntryDetail(name: string): DefinitionEntry<FragmentDefinitionNode, {
        sourcePosition: number;
    }> | undefined;
    getDuplicaterdFragmentDefinitions(): Set<string>;
    getExternalFragments(documentStr: string, fileName: string, sourcePosition: number): FragmentDefinitionNode[];
    registerDocuments(fileName: string, version: string, documentStrings: {
        text: string;
        sourcePosition: number;
    }[]): void;
    removeDocument(fileName: string): void;
}
export {};
