"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.detectDuplicatedFragments = exports.cloneFragmentMap = exports.getFragmentNamesInDocument = exports.getFragmentsInDocument = void 0;
function getFragmentsInDocument(...documentNodes) {
    const fragmentDefs = new Map();
    for (const documentNode of documentNodes) {
        if (!documentNode)
            return [];
        for (const def of documentNode.definitions) {
            if (def.kind === 'FragmentDefinition') {
                fragmentDefs.set(def.name.value, def);
            }
        }
    }
    return [...fragmentDefs.values()];
}
exports.getFragmentsInDocument = getFragmentsInDocument;
function getFragmentNamesInDocument(...documentNodes) {
    const nameSet = new Set();
    for (const documentNode of documentNodes) {
        if (!documentNode)
            return [];
        for (const def of documentNode.definitions) {
            if (def.kind === 'FragmentDefinition') {
                nameSet.add(def.name.value);
            }
        }
    }
    return [...nameSet];
}
exports.getFragmentNamesInDocument = getFragmentNamesInDocument;
function cloneFragmentMap(from, namesToBeExcluded = []) {
    const map = new Map(from);
    for (const name in namesToBeExcluded) {
        map.delete(name);
    }
    return map;
}
exports.cloneFragmentMap = cloneFragmentMap;
function detectDuplicatedFragments(documentNode) {
    const fragments = [];
    const duplicatedFragments = [];
    documentNode.definitions.forEach(def => {
        if (def.kind === 'FragmentDefinition') {
            if (fragments.some(f => f.name.value === def.name.value)) {
                duplicatedFragments.push(def);
            }
            else {
                fragments.push(def);
            }
        }
    });
    return duplicatedFragments
        .map(def => {
        return {
            name: def.name.value,
            start: def.loc.start,
            end: def.loc.end,
        };
    })
        .sort((a, b) => b.start - a.start);
}
exports.detectDuplicatedFragments = detectDuplicatedFragments;
//# sourceMappingURL=utility-functions.js.map