"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefinitionAndBoundSpan = void 0;
const graphql_1 = require("graphql");
const tsmodule_1 = __importDefault(require("../tsmodule"));
const ts_ast_util_1 = require("../ts-ast-util");
function getDefinitionAndBoundSpan(ctx, delegate, fileName, position) {
    if (ctx.getScriptSourceHelper().isExcluded(fileName))
        return delegate(fileName, position);
    const node = ctx.findAscendantTemplateNode(fileName, position);
    if (!node)
        return delegate(fileName, position);
    const { text, sourcePosition } = (0, ts_ast_util_1.getSanitizedTemplateText)(node);
    const documentNode = ctx.getGraphQLDocumentNode(text);
    if (!documentNode)
        return delegate(fileName, position);
    const innerPosition = position - sourcePosition;
    let fragmentSpreadNodeUnderCursor;
    (0, graphql_1.visit)(documentNode, {
        FragmentSpread: node => {
            if (node.name.loc.start <= innerPosition && innerPosition < node.name.loc.end) {
                fragmentSpreadNodeUnderCursor = node;
            }
        },
    });
    if (!fragmentSpreadNodeUnderCursor)
        return delegate(fileName, position);
    const foundDefinitionDetail = ctx.getGlobalFragmentDefinitionEntry(fragmentSpreadNodeUnderCursor.name.value);
    if (!foundDefinitionDetail)
        return delegate(fileName, position);
    const definitionSourcePosition = foundDefinitionDetail.position + foundDefinitionDetail.node.name.loc.start;
    return {
        textSpan: {
            start: sourcePosition + fragmentSpreadNodeUnderCursor.name.loc.start,
            length: fragmentSpreadNodeUnderCursor.name.loc.end - fragmentSpreadNodeUnderCursor.name.loc.start,
        },
        definitions: [
            {
                fileName: foundDefinitionDetail.fileName,
                name: foundDefinitionDetail.node.name.value,
                textSpan: {
                    start: definitionSourcePosition,
                    length: foundDefinitionDetail.node.name.loc.end - foundDefinitionDetail.node.name.loc.start,
                },
                kind: tsmodule_1.default.ScriptElementKind.unknown,
                containerKind: tsmodule_1.default.ScriptElementKind.unknown,
                containerName: '',
            },
        ],
    };
}
exports.getDefinitionAndBoundSpan = getDefinitionAndBoundSpan;
//# sourceMappingURL=get-definition-and-bound-span.js.map