"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getQuickInfoAtPosition = void 0;
const graphql_language_service_1 = require("graphql-language-service");
const tsmodule_1 = __importDefault(require("../tsmodule"));
const simple_position_1 = require("./simple-position");
function getQuickInfoAtPosition(ctx, delegate, fileName, position) {
    if (ctx.getScriptSourceHelper().isExcluded(fileName))
        return delegate(fileName, position);
    const schema = ctx.getSchema();
    if (!schema)
        return delegate(fileName, position);
    const node = ctx.findAscendantTemplateNode(fileName, position);
    if (!node)
        return delegate(fileName, position);
    const { resolvedInfo } = ctx.resolveTemplateInfo(fileName, node);
    if (!resolvedInfo)
        return delegate(fileName, position);
    const { combinedText, getInnerPosition, convertInnerPosition2InnerLocation } = resolvedInfo;
    const cursor = new simple_position_1.SimplePosition(convertInnerPosition2InnerLocation(getInnerPosition(position).pos));
    const result = (0, graphql_language_service_1.getHoverInformation)(schema, combinedText, cursor);
    if (typeof result !== 'string' || !result.length)
        return delegate(fileName, position);
    return {
        kind: tsmodule_1.default.ScriptElementKind.string,
        textSpan: {
            start: position,
            length: 1,
        },
        kindModifiers: '',
        displayParts: [{ text: result, kind: '' }],
    };
}
exports.getQuickInfoAtPosition = getQuickInfoAtPosition;
//# sourceMappingURL=get-quick-info-at-position.js.map