"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdapterFixture = void 0;
const ts_ast_util_1 = require("../../ts-ast-util");
const gql_ast_util_1 = require("../../gql-ast-util");
const graphql_language_service_adapter_1 = require("../graphql-language-service-adapter");
const testing_language_service_1 = require("../../ts-ast-util/testing/testing-language-service");
class AdapterFixture {
    constructor(sourceFileName, schema) {
        const { languageService, languageServiceHost } = (0, testing_language_service_1.createTestingLanguageServiceAndHost)({
            files: [{ fileName: sourceFileName, content: '' }],
        });
        this._sourceFileName = sourceFileName;
        this._langServiceHost = languageServiceHost;
        this._fragmentRegistry = new gql_ast_util_1.FragmentRegistry();
        this.langService = languageService;
        (this.scriptSourceHelper = (0, ts_ast_util_1.createScriptSourceHelper)({ languageService, languageServiceHost, project: { getProjectName: () => 'tsconfig.json' } }, { exclude: [] })),
            (this.adapter = new graphql_language_service_adapter_1.GraphQLLanguageServiceAdapter(this.scriptSourceHelper, {
                schema: schema || null,
                removeDuplicatedFragments: true,
                fragmentRegistry: this._fragmentRegistry,
                tag: {
                    names: [],
                    allowNotTaggedTemplate: true,
                    allowTaggedTemplateExpression: true,
                    allowFunctionCallExpression: true,
                },
            }));
    }
    get source() {
        return this._langServiceHost.getFile(this._sourceFileName).content;
    }
    set source(content) {
        this._langServiceHost.updateFile(this._sourceFileName, content);
        const documents = this.scriptSourceHelper
            .getAllNodes(this._sourceFileName, node => (0, ts_ast_util_1.getTemplateNodeUnder)(node, {
            names: [],
            allowNotTaggedTemplate: true,
            allowTaggedTemplateExpression: true,
            allowFunctionCallExpression: true,
        }))
            .map(node => (0, ts_ast_util_1.getSanitizedTemplateText)(node));
        this._fragmentRegistry.registerDocuments(this._sourceFileName, content, documents);
    }
    registerFragment(sourceFileName, fragmentDefDoc) {
        if (sourceFileName === this._sourceFileName)
            return this;
        this._fragmentRegistry.registerDocuments(sourceFileName, fragmentDefDoc, [
            { sourcePosition: 0, text: fragmentDefDoc },
        ]);
        return this;
    }
}
exports.AdapterFixture = AdapterFixture;
//# sourceMappingURL=adapter-fixture.js.map