"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.create = void 0;
const graphql_language_service_adapter_1 = require("../graphql-language-service-adapter");
const schema_manager_1 = require("../schema-manager");
const gql_ast_util_1 = require("../gql-ast-util");
const ts_ast_util_1 = require("../ts-ast-util");
const language_service_proxy_builder_1 = require("./language-service-proxy-builder");
function create(info) {
    const logger = (msg) => info.project.projectService.logger.info(`[ts-graphql-plugin] ${msg}`);
    logger('config: ' + JSON.stringify(info.config));
    const schemaManager = new schema_manager_1.SchemaManagerFactory((0, schema_manager_1.createSchemaManagerHostFromLSPluginInfo)(info)).create();
    const { schema, errors: schemaErrors } = schemaManager.getSchema();
    const config = info.config;
    const tag = (0, ts_ast_util_1.parseTagConfig)(config.tag);
    const removeDuplicatedFragments = config.removeDuplicatedFragments === false ? false : true;
    const enabledGlobalFragments = config.enabledGlobalFragments !== false;
    const isExcluded = (0, ts_ast_util_1.createFileNameFilter)({ specs: config.exclude, projectName: info.project.getProjectName() });
    const fragmentRegistry = new gql_ast_util_1.FragmentRegistry({ logger });
    if (enabledGlobalFragments) {
        const handleAcquireOrUpdate = (fileName, sourceFile, version) => {
            fragmentRegistry.registerDocuments(fileName, version, (0, ts_ast_util_1.findAllNodes)(sourceFile, node => (0, ts_ast_util_1.getTemplateNodeUnder)(node, tag)).map(node => (0, ts_ast_util_1.getSanitizedTemplateText)(node, sourceFile)));
        };
        (0, ts_ast_util_1.registerDocumentChangeEvent)(
        // Note:
        // documentRegistry in ts.server.Project is annotated @internal
        info.project.documentRegistry, {
            onAcquire: (fileName, sourceFile, version) => {
                if (!isExcluded(fileName) && info.languageServiceHost.getScriptFileNames().includes(fileName)) {
                    handleAcquireOrUpdate(fileName, sourceFile, version);
                }
            },
            onUpdate: (fileName, sourceFile, version) => {
                if (!isExcluded(fileName) && info.languageServiceHost.getScriptFileNames().includes(fileName)) {
                    if (fragmentRegistry.getFileCurrentVersion(fileName) === version)
                        return;
                    handleAcquireOrUpdate(fileName, sourceFile, version);
                }
            },
            onRelease: fileName => {
                fragmentRegistry.removeDocument(fileName);
            },
        });
    }
    const scriptSourceHelper = (0, ts_ast_util_1.createScriptSourceHelper)(info, { exclude: config.exclude });
    const adapter = new graphql_language_service_adapter_1.GraphQLLanguageServiceAdapter(scriptSourceHelper, {
        schema,
        schemaErrors,
        logger,
        tag,
        fragmentRegistry,
        removeDuplicatedFragments,
    });
    const proxy = new language_service_proxy_builder_1.LanguageServiceProxyBuilder(info)
        .wrap('getCompletionsAtPosition', delegate => adapter.getCompletionAtPosition.bind(adapter, delegate))
        .wrap('getSemanticDiagnostics', delegate => adapter.getSemanticDiagnostics.bind(adapter, delegate))
        .wrap('getQuickInfoAtPosition', delegate => adapter.getQuickInfoAtPosition.bind(adapter, delegate))
        .wrap('getDefinitionAndBoundSpan', delegate => adapter.getDefinitionAndBoundSpan.bind(adapter, delegate))
        .wrap('getDefinitionAtPosition', delegate => adapter.getDefinitionAtPosition.bind(adapter, delegate))
        .build();
    schemaManager.registerOnChange(adapter.updateSchema.bind(adapter));
    schemaManager.start();
    return proxy;
}
exports.create = create;
//# sourceMappingURL=create-plugin.js.map