"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createScriptSourceHelper = void 0;
const tsmodule_1 = __importDefault(require("../tsmodule"));
const utilily_functions_1 = require("./utilily-functions");
const template_expression_resolver_1 = require("./template-expression-resolver");
const file_name_filter_1 = require("./file-name-filter");
function createScriptSourceHelper({ languageService, languageServiceHost, project, }, { exclude, reuseProgram, }) {
    let cachedProgram;
    const getSourceFile = (fileName) => {
        // Note:
        // Reuse program in batching procedure(e.g. CLI) because getProgram() is "heavy" function.
        const program = cachedProgram !== null && cachedProgram !== void 0 ? cachedProgram : languageService.getProgram();
        if (!program) {
            throw new Error('language service host does not have program!');
        }
        if (reuseProgram)
            cachedProgram = program;
        const s = program.getSourceFile(fileName);
        if (!s) {
            throw new Error('No source file: ' + fileName);
        }
        return s;
    };
    const isExcluded = (0, file_name_filter_1.createFileNameFilter)({ specs: exclude, projectName: project.getProjectName() });
    const getNode = (fileName, position) => {
        return (0, utilily_functions_1.findNode)(getSourceFile(fileName), position);
    };
    const getAllNodes = (fileName, cond) => {
        const s = getSourceFile(fileName);
        return (0, utilily_functions_1.findAllNodes)(s, cond);
    };
    const getLineAndChar = (fileName, position) => {
        const s = getSourceFile(fileName);
        return tsmodule_1.default.getLineAndCharacterOfPosition(s, position);
    };
    const resolver = new template_expression_resolver_1.TemplateExpressionResolver(languageService, (fileName) => languageServiceHost.getScriptVersion(fileName), isExcluded);
    const resolveTemplateLiteral = resolver.resolve.bind(resolver);
    const updateTemplateLiteralInfo = resolver.update.bind(resolver);
    return {
        isExcluded,
        getNode,
        getAllNodes,
        getLineAndChar,
        resolveTemplateLiteral,
        updateTemplateLiteralInfo,
    };
}
exports.createScriptSourceHelper = createScriptSourceHelper;
//# sourceMappingURL=script-source-helper.js.map