"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTagName = exports.isTaggedTemplateNode = exports.getTemplateNodeUnder = exports.parseTagConfig = exports.DEFAULT_TAG_CONDITION = void 0;
const tsmodule_1 = __importDefault(require("../tsmodule"));
exports.DEFAULT_TAG_CONDITION = {
    names: ['gql', 'graphql'],
    allowNotTaggedTemplate: false,
    allowTaggedTemplateExpression: true,
    allowFunctionCallExpression: true,
};
function parseTagConfig(tagConfig) {
    const parseName = (name) => {
        if (typeof name === 'string') {
            return [name];
        }
        else if (Array.isArray(name)) {
            return name.map(n => n.toString());
        }
        else {
            return [];
        }
    };
    if (tagConfig == null) {
        return exports.DEFAULT_TAG_CONDITION;
    }
    if (tagConfig === '') {
        return {
            names: [],
            allowNotTaggedTemplate: true,
            allowTaggedTemplateExpression: true,
            allowFunctionCallExpression: false,
        };
    }
    if (typeof tagConfig === 'string' || Array.isArray(tagConfig)) {
        return {
            names: parseName(tagConfig),
            allowNotTaggedTemplate: false,
            allowTaggedTemplateExpression: true,
            allowFunctionCallExpression: false,
        };
    }
    const names = parseName(tagConfig.name);
    return {
        names,
        allowNotTaggedTemplate: false,
        allowTaggedTemplateExpression: true,
        allowFunctionCallExpression: tagConfig.ignoreFunctionCallExpression == null
            ? false // Change behavior at v4
            : tagConfig.ignoreFunctionCallExpression === false
                ? true
                : false,
    };
}
exports.parseTagConfig = parseTagConfig;
function getTemplateNodeUnder(node, { allowFunctionCallExpression, allowNotTaggedTemplate, allowTaggedTemplateExpression, names }) {
    if (!node)
        return undefined;
    if (allowTaggedTemplateExpression && tsmodule_1.default.isTaggedTemplateExpression(node) && tsmodule_1.default.isIdentifier(node.tag)) {
        if (names.includes(node.tag.escapedText)) {
            return node.template;
        }
    }
    if (allowFunctionCallExpression &&
        tsmodule_1.default.isCallExpression(node) &&
        tsmodule_1.default.isIdentifier(node.expression) &&
        node.arguments.length > 0) {
        const firstArg = node.arguments[0];
        if (!tsmodule_1.default.isTemplateLiteral(firstArg))
            return;
        if (names.includes(node.expression.escapedText)) {
            return firstArg;
        }
    }
    if (allowNotTaggedTemplate && tsmodule_1.default.isTemplateLiteral(node)) {
        return node;
    }
}
exports.getTemplateNodeUnder = getTemplateNodeUnder;
function isTaggedTemplateNode(node, tagCondition) {
    if (tagCondition.allowNotTaggedTemplate)
        return true;
    return !!getTemplateNodeUnder(node.parent, tagCondition);
}
exports.isTaggedTemplateNode = isTaggedTemplateNode;
function getTagName(node, { allowNotTaggedTemplate, allowFunctionCallExpression, allowTaggedTemplateExpression, names }) {
    if (!node.parent)
        return undefined;
    if (!tsmodule_1.default.isCallExpression(node.parent) && !tsmodule_1.default.isTaggedTemplateExpression(node.parent)) {
        return allowNotTaggedTemplate ? '' : undefined;
    }
    if (allowFunctionCallExpression && tsmodule_1.default.isCallExpression(node.parent) && tsmodule_1.default.isIdentifier(node.parent.expression)) {
        const name = node.parent.expression.escapedText;
        return names.includes(name) ? name : allowNotTaggedTemplate ? '' : undefined;
    }
    if (allowTaggedTemplateExpression && tsmodule_1.default.isTaggedTemplateExpression(node.parent) && tsmodule_1.default.isIdentifier(node.parent.tag)) {
        const name = node.parent.tag.escapedText;
        return names.includes(name) ? name : allowNotTaggedTemplate ? '' : undefined;
    }
    return undefined;
}
exports.getTagName = getTagName;
//# sourceMappingURL=tag-utils.js.map